Coverage report

# Coverage report: 2%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 84661 | 82698 | 4 | 2%
future\__init__.py | 9 | 0 | 0 | 100%
future\utils\__init__.py | 280 | 201 | 0 | 28%
rocketcea\Goal.py | 79 | 1 | 0 | 99%
rocketcea\Isp.py | 96 | 7 | 0 | 93%
rocketcea\__init__.py | 3 | 0 | 0 | 100%
rocketcea\biprop_utils\InterpProp_scipy.py | 113 | 104 | 0 | 8%
rocketcea\biprop_utils\__init__.py | 0 | 0 | 0 | 100%
rocketcea\biprop_utils\back_terp.py | 63 | 57 | 0 | 10%
rocketcea\biprop_utils\calc_plot_range.py | 40 | 36 | 0 | 10%
rocketcea\biprop_utils\contour_supt.py | 39 | 33 | 0 | 15%
rocketcea\biprop_utils\density_at_mr.py | 60 | 17 | 0 | 72%
rocketcea\biprop_utils\goldSearch.py | 43 | 37 | 0 | 14%
rocketcea\biprop_utils\mr_peak_at_eps_pc.py | 147 | 127 | 0 | 14%
rocketcea\biprop_utils\mr_t_limits.py | 62 | 0 | 0 | 100%
rocketcea\biprop_utils\rho_isp_plot_obj.py | 329 | 304 | 0 | 8%
rocketcea\biprop_utils\run_cea_w_error_corr.py | 66 | 4 | 0 | 94%
rocketcea\biprop_utils\veh_stage_obj.py | 219 | 192 | 0 | 12%
rocketcea\blends.py | 358 | 57 | 0 | 84%
rocketcea\cea_obj.py | 776 | 125 | 0 | 84%
rocketcea\cea_obj_w_units.py | 287 | 5 | 0 | 98%
rocketcea\input_cards.py | 11 | 0 | 0 | 100%
rocketcea\separated_Cf.py | 71 | 1 | 0 | 99%
rocketcea\units.py | 168 | 48 | 0 | 71%
csv.py | 259 | 259 | 0 | 0%
ctypes\__init__.py | 334 | 334 | 0 | 0%
ctypes\_endian.py | 35 | 35 | 0 | 0%
ctypes\wintypes.py | 130 | 130 | 0 | 0%
decimal.py | 10 | 10 | 0 | 0%
distutils\__init__.py | 2 | 2 | 0 | 0%
distutils\version.py | 100 | 100 | 0 | 0%
gzip.py | 349 | 349 | 0 | 0%
numbers.py | 134 | 134 | 0 | 0%
pathlib.py | 874 | 874 | 0 | 0%
PIL\Image.py | 1150 | 1150 | 0 | 0%
PIL\ImageMode.py | 24 | 24 | 0 | 0%
PIL\__init__.py | 6 | 6 | 0 | 0%
PIL\_binary.py | 31 | 31 | 0 | 0%
PIL\_util.py | 18 | 18 | 0 | 0%
PIL\_version.py | 1 | 1 | 0 | 0%
cffi\__init__.py | 7 | 7 | 0 | 0%
cffi\api.py | 543 | 543 | 0 | 0%
cffi\error.py | 19 | 19 | 0 | 0%
cffi\lock.py | 10 | 10 | 0 | 0%
cffi\model.py | 387 | 387 | 0 | 0%
cycler.py | 175 | 175 | 0 | 0%
dateutil\__init__.py | 5 | 5 | 0 | 0%
dateutil\_common.py | 25 | 25 | 0 | 0%
dateutil\_version.py | 1 | 1 | 0 | 0%
dateutil\parser\__init__.py | 32 | 32 | 0 | 0%
dateutil\parser\_parser.py | 795 | 795 | 4 | 0%
dateutil\parser\isoparser.py | 172 | 172 | 0 | 0%
dateutil\relativedelta.py | 239 | 239 | 0 | 0%
dateutil\rrule.py | 971 | 971 | 0 | 0%
dateutil\tz\__init__.py | 5 | 5 | 0 | 0%
dateutil\tz\_common.py | 153 | 153 | 0 | 0%
dateutil\tz\_factories.py | 32 | 32 | 0 | 0%
dateutil\tz\tz.py | 760 | 760 | 0 | 0%
dateutil\tz\win.py | 150 | 150 | 0 | 0%
matplotlib\__init__.py | 837 | 837 | 0 | 0%
matplotlib\_cm.py | 97 | 97 | 0 | 0%
matplotlib\_cm_listed.py | 11 | 11 | 0 | 0%
matplotlib\_color_data.py | 9 | 9 | 0 | 0%
matplotlib\_constrained_layout.py | 293 | 293 | 0 | 0%
matplotlib\_layoutbox.py | 426 | 426 | 0 | 0%
matplotlib\_mathtext_data.py | 9 | 9 | 0 | 0%
matplotlib\_pylab_helpers.py | 58 | 58 | 0 | 0%
matplotlib\_version.py | 5 | 5 | 0 | 0%
matplotlib\afm.py | 253 | 253 | 0 | 0%
matplotlib\artist.py | 587 | 587 | 0 | 0%
matplotlib\axes\__init__.py | 3 | 3 | 0 | 0%
matplotlib\axes\_axes.py | 2366 | 2366 | 0 | 0%
matplotlib\axes\_base.py | 1668 | 1668 | 0 | 0%
matplotlib\axes\_subplots.py | 117 | 117 | 0 | 0%
matplotlib\axis.py | 1306 | 1306 | 0 | 0%
matplotlib\backend_bases.py | 1250 | 1250 | 0 | 0%
matplotlib\backend_tools.py | 536 | 536 | 0 | 0%
matplotlib\backends\__init__.py | 33 | 33 | 0 | 0%
matplotlib\backends\backend_agg.py | 299 | 299 | 0 | 0%
matplotlib\bezier.py | 206 | 206 | 0 | 0%
matplotlib\blocking_input.py | 149 | 149 | 0 | 0%
matplotlib\category.py | 70 | 70 | 0 | 0%
matplotlib\cbook\__init__.py | 1226 | 1226 | 0 | 0%
matplotlib\cbook\_backports.py | 57 | 57 | 0 | 0%
matplotlib\cbook\deprecation.py | 61 | 61 | 0 | 0%
matplotlib\cm.py | 164 | 164 | 0 | 0%
matplotlib\collections.py | 808 | 808 | 0 | 0%
matplotlib\colorbar.py | 637 | 637 | 0 | 0%
matplotlib\colors.py | 815 | 815 | 0 | 0%
matplotlib\compat\__init__.py | 0 | 0 | 0 | 100%
matplotlib\compat\subprocess.py | 24 | 24 | 0 | 0%
matplotlib\container.py | 67 | 67 | 0 | 0%
matplotlib\contour.py | 761 | 761 | 0 | 0%
matplotlib\dates.py | 687 | 687 | 0 | 0%
matplotlib\docstring.py | 42 | 42 | 0 | 0%
matplotlib\dviread.py | 475 | 475 | 0 | 0%
matplotlib\figure.py | 797 | 797 | 0 | 0%
matplotlib\font_manager.py | 673 | 673 | 0 | 0%
matplotlib\fontconfig_pattern.py | 73 | 73 | 0 | 0%
matplotlib\gridspec.py | 241 | 241 | 0 | 0%
matplotlib\image.py | 670 | 670 | 0 | 0%
matplotlib\legend.py | 441 | 441 | 0 | 0%
matplotlib\legend_handler.py | 318 | 318 | 0 | 0%
matplotlib\lines.py | 693 | 693 | 0 | 0%
matplotlib\markers.py | 485 | 485 | 0 | 0%
matplotlib\mathtext.py | 1711 | 1711 | 0 | 0%
matplotlib\mlab.py | 1373 | 1373 | 0 | 0%
matplotlib\offsetbox.py | 748 | 748 | 0 | 0%
matplotlib\patches.py | 1786 | 1786 | 0 | 0%
matplotlib\path.py | 357 | 357 | 0 | 0%
matplotlib\projections\__init__.py | 44 | 44 | 0 | 0%
matplotlib\projections\geo.py | 315 | 315 | 0 | 0%
matplotlib\projections\polar.py | 758 | 758 | 0 | 0%
matplotlib\pylab.py | 17 | 17 | 0 | 0%
matplotlib\pyplot.py | 1360 | 1360 | 0 | 0%
matplotlib\quiver.py | 458 | 458 | 0 | 0%
matplotlib\rcsetup.py | 490 | 490 | 0 | 0%
matplotlib\scale.py | 285 | 285 | 0 | 0%
matplotlib\spines.py | 288 | 288 | 0 | 0%
matplotlib\stackplot.py | 49 | 49 | 0 | 0%
matplotlib\streamplot.py | 370 | 370 | 0 | 0%
matplotlib\style\__init__.py | 2 | 2 | 0 | 0%
matplotlib\style\core.py | 98 | 98 | 0 | 0%
matplotlib\table.py | 350 | 350 | 0 | 0%
matplotlib\texmanager.py | 244 | 244 | 0 | 0%
matplotlib\text.py | 993 | 993 | 0 | 0%
matplotlib\textpath.py | 273 | 273 | 0 | 0%
matplotlib\ticker.py | 1235 | 1235 | 0 | 0%
matplotlib\tight_bbox.py | 45 | 45 | 0 | 0%
matplotlib\tight_layout.py | 160 | 160 | 0 | 0%
matplotlib\transforms.py | 1204 | 1204 | 0 | 0%
matplotlib\tri\__init__.py | 10 | 10 | 0 | 0%
matplotlib\tri\triangulation.py | 90 | 90 | 0 | 0%
matplotlib\tri\tricontour.py | 59 | 59 | 0 | 0%
matplotlib\tri\trifinder.py | 28 | 28 | 0 | 0%
matplotlib\tri\triinterpolate.py | 568 | 568 | 0 | 0%
matplotlib\tri\tripcolor.py | 70 | 70 | 0 | 0%
matplotlib\tri\triplot.py | 32 | 32 | 0 | 0%
matplotlib\tri\trirefine.py | 96 | 96 | 0 | 0%
matplotlib\tri\tritools.py | 86 | 86 | 0 | 0%
matplotlib\units.py | 58 | 58 | 0 | 0%
matplotlib\widgets.py | 1393 | 1393 | 0 | 0%
numpy\__config__.py | 25 | 25 | 0 | 0%
numpy\__init__.py | 64 | 64 | 0 | 0%
numpy\_distributor_init.py | 21 | 21 | 0 | 0%
numpy\_globals.py | 20 | 20 | 0 | 0%
numpy\_pytesttester.py | 48 | 48 | 0 | 0%
numpy\compat\__init__.py | 8 | 8 | 0 | 0%
numpy\compat\_inspect.py | 68 | 68 | 0 | 0%
numpy\compat\py3k.py | 117 | 117 | 0 | 0%
numpy\core\__init__.py | 72 | 72 | 0 | 0%
numpy\core\_add_newdocs.py | 300 | 300 | 0 | 0%
numpy\core\_dtype.py | 154 | 154 | 0 | 0%
numpy\core\_dtype_ctypes.py | 53 | 53 | 0 | 0%
numpy\core\_internal.py | 439 | 439 | 0 | 0%
numpy\core\_methods.py | 90 | 90 | 0 | 0%
numpy\core\_string_helpers.py | 15 | 15 | 0 | 0%
numpy\core\_type_aliases.py | 152 | 152 | 0 | 0%
numpy\core\arrayprint.py | 550 | 550 | 0 | 0%
numpy\core\defchararray.py | 422 | 422 | 0 | 0%
numpy\core\einsumfunc.py | 408 | 408 | 0 | 0%
numpy\core\fromnumeric.py | 352 | 352 | 0 | 0%
numpy\core\function_base.py | 107 | 107 | 0 | 0%
numpy\core\getlimits.py | 198 | 198 | 0 | 0%
numpy\core\info.py | 3 | 3 | 0 | 0%
numpy\core\machar.py | 189 | 189 | 0 | 0%
numpy\core\memmap.py | 91 | 91 | 0 | 0%
numpy\core\multiarray.py | 98 | 98 | 0 | 0%
numpy\core\numeric.py | 588 | 588 | 0 | 0%
numpy\core\numerictypes.py | 161 | 161 | 0 | 0%
numpy\core\overrides.py | 49 | 49 | 0 | 0%
numpy\core\records.py | 367 | 367 | 0 | 0%
numpy\core\shape_base.py | 185 | 185 | 0 | 0%
numpy\core\umath.py | 4 | 4 | 0 | 0%
numpy\ctypeslib.py | 213 | 213 | 0 | 0%
numpy\dual.py | 42 | 42 | 0 | 0%
numpy\fft\__init__.py | 7 | 7 | 0 | 0%
numpy\fft\fftpack.py | 154 | 154 | 0 | 0%
numpy\fft\helper.py | 86 | 86 | 0 | 0%
numpy\fft\info.py | 2 | 2 | 0 | 0%
numpy\lib\__init__.py | 44 | 44 | 0 | 0%
numpy\lib\_datasource.py | 221 | 221 | 0 | 0%
numpy\lib\_iotools.py | 388 | 388 | 0 | 0%
numpy\lib\_version.py | 77 | 77 | 0 | 0%
numpy\lib\arraypad.py | 346 | 346 | 0 | 0%
numpy\lib\arraysetops.py | 185 | 185 | 0 | 0%
numpy\lib\arrayterator.py | 73 | 73 | 0 | 0%
numpy\lib\financial.py | 140 | 140 | 0 | 0%
numpy\lib\format.py | 257 | 257 | 0 | 0%
numpy\lib\function_base.py | 1188 | 1188 | 0 | 0%
numpy\lib\histograms.py | 277 | 277 | 0 | 0%
numpy\lib\index_tricks.py | 256 | 256 | 0 | 0%
numpy\lib\info.py | 3 | 3 | 0 | 0%
numpy\lib\mixins.py | 63 | 63 | 0 | 0%
numpy\lib\nanfunctions.py | 272 | 272 | 0 | 0%
numpy\lib\npyio.py | 875 | 875 | 0 | 0%
numpy\lib\polynomial.py | 426 | 426 | 0 | 0%
numpy\lib\scimath.py | 62 | 62 | 0 | 0%
numpy\lib\shape_base.py | 247 | 247 | 0 | 0%
numpy\lib\stride_tricks.py | 68 | 68 | 0 | 0%
numpy\lib\twodim_base.py | 152 | 152 | 0 | 0%
numpy\lib\type_check.py | 125 | 125 | 0 | 0%
numpy\lib\ufunclike.py | 54 | 54 | 0 | 0%
numpy\lib\utils.py | 514 | 514 | 0 | 0%
numpy\linalg\__init__.py | 6 | 6 | 0 | 0%
numpy\linalg\info.py | 2 | 2 | 0 | 0%
numpy\linalg\linalg.py | 664 | 664 | 0 | 0%
numpy\ma\__init__.py | 11 | 11 | 0 | 0%
numpy\ma\core.py | 2416 | 2416 | 0 | 0%
numpy\ma\extras.py | 557 | 557 | 0 | 0%
numpy\matrixlib\__init__.py | 6 | 6 | 0 | 0%
numpy\matrixlib\defmatrix.py | 234 | 234 | 0 | 0%
numpy\polynomial\__init__.py | 10 | 10 | 0 | 0%
numpy\polynomial\_polybase.py | 352 | 352 | 0 | 0%
numpy\polynomial\chebyshev.py | 484 | 484 | 0 | 0%
numpy\polynomial\hermite.py | 422 | 422 | 0 | 0%
numpy\polynomial\hermite_e.py | 419 | 419 | 0 | 0%
numpy\polynomial\laguerre.py | 408 | 408 | 0 | 0%
numpy\polynomial\legendre.py | 416 | 416 | 0 | 0%
numpy\polynomial\polynomial.py | 353 | 353 | 0 | 0%
numpy\polynomial\polyutils.py | 65 | 65 | 0 | 0%
numpy\random\__init__.py | 13 | 13 | 0 | 0%
numpy\version.py | 7 | 7 | 0 | 0%
pylab.py | 3 | 3 | 0 | 0%
pyparsing.py | 2522 | 2522 | 0 | 0%
scipy\__config__.py | 25 | 25 | 0 | 0%
scipy\__init__.py | 41 | 41 | 0 | 0%
scipy\_distributor_init.py | 0 | 0 | 0 | 100%
scipy\_lib\__init__.py | 4 | 4 | 0 | 0%
scipy\_lib\_ccallback.py | 95 | 95 | 0 | 0%
scipy\_lib\_numpy_compat.py | 274 | 274 | 0 | 0%
scipy\_lib\_util.py | 161 | 161 | 0 | 0%
scipy\_lib\_version.py | 76 | 76 | 0 | 0%
scipy\_lib\decorator.py | 252 | 252 | 0 | 0%
scipy\_lib\six.py | 176 | 176 | 0 | 0%
scipy\interpolate\__init__.py | 15 | 15 | 0 | 0%
scipy\interpolate\_bsplines.py | 323 | 323 | 0 | 0%
scipy\interpolate\_cubic.py | 256 | 256 | 0 | 0%
scipy\interpolate\_fitpack_impl.py | 413 | 413 | 0 | 0%
scipy\interpolate\_pade.py | 27 | 27 | 0 | 0%
scipy\interpolate\fitpack.py | 65 | 65 | 0 | 0%
scipy\interpolate\fitpack2.py | 361 | 361 | 0 | 0%
scipy\interpolate\interpolate.py | 912 | 912 | 0 | 0%
scipy\interpolate\ndgriddata.py | 47 | 47 | 0 | 0%
scipy\interpolate\polyint.py | 203 | 203 | 0 | 0%
scipy\interpolate\rbf.py | 90 | 90 | 0 | 0%
scipy\linalg\__init__.py | 36 | 36 | 0 | 0%
scipy\linalg\_decomp_ldl.py | 85 | 85 | 0 | 0%
scipy\linalg\_decomp_polar.py | 16 | 16 | 0 | 0%
scipy\linalg\_decomp_qz.py | 127 | 127 | 0 | 0%
scipy\linalg\_expm_frechet.py | 153 | 153 | 0 | 0%
scipy\linalg\_matfuncs_sqrtm.py | 85 | 85 | 0 | 0%
scipy\linalg\_procrustes.py | 18 | 18 | 0 | 0%
scipy\linalg\_sketches.py | 15 | 15 | 0 | 0%
scipy\linalg\_solvers.py | 216 | 216 | 0 | 0%
scipy\linalg\basic.py | 383 | 383 | 0 | 0%
scipy\linalg\blas.py | 64 | 64 | 0 | 0%
scipy\linalg\decomp.py | 364 | 364 | 0 | 0%
scipy\linalg\decomp_cholesky.py | 72 | 72 | 0 | 0%
scipy\linalg\decomp_lu.py | 48 | 48 | 0 | 0%
scipy\linalg\decomp_qr.py | 130 | 130 | 0 | 0%
scipy\linalg\decomp_schur.py | 104 | 104 | 0 | 0%
scipy\linalg\decomp_svd.py | 88 | 88 | 0 | 0%
scipy\linalg\flinalg.py | 30 | 30 | 0 | 0%
scipy\linalg\lapack.py | 46 | 46 | 0 | 0%
scipy\linalg\linalg_version.py | 5 | 5 | 0 | 0%
scipy\linalg\matfuncs.py | 130 | 130 | 0 | 0%
scipy\linalg\misc.py | 40 | 40 | 0 | 0%
scipy\linalg\special_matrices.py | 223 | 223 | 0 | 0%
scipy\sparse\__init__.py | 19 | 19 | 0 | 0%
scipy\sparse\_index.py | 217 | 217 | 0 | 0%
scipy\sparse\_matrix_io.py | 42 | 42 | 0 | 0%
scipy\sparse\base.py | 452 | 452 | 0 | 0%
scipy\sparse\bsr.py | 313 | 313 | 0 | 0%
scipy\sparse\compressed.py | 736 | 736 | 0 | 0%
scipy\sparse\construct.py | 232 | 232 | 0 | 0%
scipy\sparse\coo.py | 294 | 294 | 0 | 0%
scipy\sparse\csc.py | 87 | 87 | 0 | 0%
scipy\sparse\csgraph\__init__.py | 12 | 12 | 0 | 0%
scipy\sparse\csgraph\_laplacian.py | 51 | 51 | 0 | 0%
scipy\sparse\csgraph\_validation.py | 31 | 31 | 0 | 0%
scipy\sparse\csr.py | 135 | 135 | 0 | 0%
scipy\sparse\data.py | 182 | 182 | 0 | 0%
scipy\sparse\dia.py | 224 | 224 | 0 | 0%
scipy\sparse\dok.py | 275 | 275 | 0 | 0%
scipy\sparse\extract.py | 22 | 22 | 0 | 0%
scipy\sparse\lil.py | 279 | 279 | 0 | 0%
scipy\sparse\sputils.py | 178 | 178 | 0 | 0%
scipy\spatial\__init__.py | 13 | 13 | 0 | 0%
scipy\spatial\_plotutils.py | 76 | 76 | 0 | 0%
scipy\spatial\_procrustes.py | 25 | 25 | 0 | 0%
scipy\spatial\_spherical_voronoi.py | 62 | 62 | 0 | 0%
scipy\spatial\distance.py | 633 | 633 | 0 | 0%
scipy\spatial\kdtree.py | 416 | 416 | 0 | 0%
scipy\spatial\transform\__init__.py | 7 | 7 | 0 | 0%
scipy\spatial\transform\_rotation_spline.py | 176 | 176 | 0 | 0%
scipy\spatial\transform\rotation.py | 348 | 348 | 0 | 0%
scipy\special\__init__.py | 63 | 63 | 0 | 0%
scipy\special\_ellip_harm.py | 16 | 16 | 0 | 0%
scipy\special\_logsumexp.py | 34 | 34 | 0 | 0%
scipy\special\_spherical_bessel.py | 18 | 18 | 0 | 0%
scipy\special\basic.py | 525 | 525 | 0 | 0%
scipy\special\lambertw.py | 4 | 4 | 0 | 0%
scipy\special\orthogonal.py | 525 | 525 | 0 | 0%
scipy\special\sf_error.py | 6 | 6 | 0 | 0%
scipy\special\spfun_stats.py | 14 | 14 | 0 | 0%
scipy\version.py | 7 | 7 | 0 | 0%
six.py | 450 | 450 | 0 | 0%

No items found using the specified filter.